==> zio-aws-dataexchange_2.13-5.17.130.5-sources.jar: zio/aws/dataexchange/model/CreateEventActionResponse.scala <==
package zio.aws.dataexchange.model
import zio.aws.dataexchange.model.primitives.{Id, Timestamp, Arn}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import scala.jdk.CollectionConverters._
final case class CreateEventActionResponse(
    action: Option[zio.aws.dataexchange.model.Action] = None,
    arn: Option[Arn] = None,
    createdAt: Option[Timestamp] = None,
    event: Option[zio.aws.dataexchange.model.Event] = None,
    id: Option[Id] = None,
    updatedAt: Option[Timestamp] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dataexchange.model.CreateEventActionResponse = {
    import CreateEventActionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dataexchange.model.CreateEventActionResponse
      .builder()
      .optionallyWith(action.map(value => value.buildAwsValue()))(_.action)
      .optionallyWith(arn.map(value => Arn.unwrap(value): java.lang.String))(
        _.arn
      )
      .optionallyWith(createdAt.map(value => Timestamp.unwrap(value): Instant))(
        _.createdAt
      )
      .optionallyWith(event.map(value => value.buildAwsValue()))(_.event)
      .optionallyWith(id.map(value => Id.unwrap(value): java.lang.String))(_.id)
      .optionallyWith(updatedAt.map(value => Timestamp.unwrap(value): Instant))(
        _.updatedAt
      )
      .build()
  }
  def asReadOnly
      : zio.aws.dataexchange.model.CreateEventActionResponse.ReadOnly =
    zio.aws.dataexchange.model.CreateEventActionResponse.wrap(buildAwsValue())
}
object CreateEventActionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dataexchange.model.CreateEventActionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dataexchange.model.CreateEventActionResponse =
      zio.aws.dataexchange.model.CreateEventActionResponse(
        action.map(value => value.asEditable),
        arn.map(value => value),
        createdAt.map(value => value),
        event.map(value => value.asEditable),
        id.map(value => value),
        updatedAt.map(value => value)
      )
    def action: Option[zio.aws.dataexchange.model.Action.ReadOnly]
    def arn: Option[Arn]
    def createdAt: Option[Timestamp]
    def event: Option[zio.aws.dataexchange.model.Event.ReadOnly]
    def id: Option[Id]
    def updatedAt: Option[Timestamp]
    def getAction
        : ZIO[Any, AwsError, zio.aws.dataexchange.model.Action.ReadOnly] =
      AwsError.unwrapOptionField("action", action)
    def getArn: ZIO[Any, AwsError, Arn] = AwsError.unwrapOptionField("arn", arn)
    def getCreatedAt: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("createdAt", createdAt)
    def getEvent
        : ZIO[Any, AwsError, zio.aws.dataexchange.model.Event.ReadOnly] =
      AwsError.unwrapOptionField("event", event)
    def getId: ZIO[Any, AwsError, Id] = AwsError.unwrapOptionField("id", id)
    def getUpdatedAt: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("updatedAt", updatedAt)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dataexchange.model.CreateEventActionResponse
  ) extends zio.aws.dataexchange.model.CreateEventActionResponse.ReadOnly {
    override val action: Option[zio.aws.dataexchange.model.Action.ReadOnly] =
      scala
        .Option(impl.action())
        .map(value => zio.aws.dataexchange.model.Action.wrap(value))
    override val arn: Option[Arn] = scala
      .Option(impl.arn())
      .map(value => zio.aws.dataexchange.model.primitives.Arn(value))
    override val createdAt: Option[Timestamp] = scala
      .Option(impl.createdAt())
      .map(value => zio.aws.dataexchange.model.primitives.Timestamp(value))
    override val event: Option[zio.aws.dataexchange.model.Event.ReadOnly] =
      scala
        .Option(impl.event())
        .map(value => zio.aws.dataexchange.model.Event.wrap(value))
    override val id: Option[Id] = scala
      .Option(impl.id())
      .map(value => zio.aws.dataexchange.model.primitives.Id(value))
    override val updatedAt: Option[Timestamp] = scala
      .Option(impl.updatedAt())
      .map(value => zio.aws.dataexchange.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.dataexchange.model.CreateEventActionResponse
  ): zio.aws.dataexchange.model.CreateEventActionResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-dataexchange_2.13-5.17.267.1-sources.jar: zio/aws/dataexchange/model/CreateEventActionResponse.scala <==
package zio.aws.dataexchange.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.dataexchange.model.primitives.{Id, Timestamp, Arn}
import scala.jdk.CollectionConverters._
final case class CreateEventActionResponse(
    action: Optional[zio.aws.dataexchange.model.Action] = Optional.Absent,
    arn: Optional[Arn] = Optional.Absent,
    createdAt: Optional[Timestamp] = Optional.Absent,
    event: Optional[zio.aws.dataexchange.model.Event] = Optional.Absent,
    id: Optional[Id] = Optional.Absent,
    updatedAt: Optional[Timestamp] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.dataexchange.model.CreateEventActionResponse = {
    import CreateEventActionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.dataexchange.model.CreateEventActionResponse
      .builder()
      .optionallyWith(action.map(value => value.buildAwsValue()))(_.action)
      .optionallyWith(arn.map(value => Arn.unwrap(value): java.lang.String))(
        _.arn
      )
      .optionallyWith(createdAt.map(value => Timestamp.unwrap(value): Instant))(
        _.createdAt
      )
      .optionallyWith(event.map(value => value.buildAwsValue()))(_.event)
      .optionallyWith(id.map(value => Id.unwrap(value): java.lang.String))(_.id)
      .optionallyWith(updatedAt.map(value => Timestamp.unwrap(value): Instant))(
        _.updatedAt
      )
      .build()
  }
  def asReadOnly
      : zio.aws.dataexchange.model.CreateEventActionResponse.ReadOnly =
    zio.aws.dataexchange.model.CreateEventActionResponse.wrap(buildAwsValue())
}
object CreateEventActionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.dataexchange.model.CreateEventActionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.dataexchange.model.CreateEventActionResponse =
      zio.aws.dataexchange.model.CreateEventActionResponse(
        action.map(value => value.asEditable),
        arn.map(value => value),
        createdAt.map(value => value),
        event.map(value => value.asEditable),
        id.map(value => value),
        updatedAt.map(value => value)
      )
    def action: Optional[zio.aws.dataexchange.model.Action.ReadOnly]
    def arn: Optional[Arn]
    def createdAt: Optional[Timestamp]
    def event: Optional[zio.aws.dataexchange.model.Event.ReadOnly]
    def id: Optional[Id]
    def updatedAt: Optional[Timestamp]
    def getAction
        : ZIO[Any, AwsError, zio.aws.dataexchange.model.Action.ReadOnly] =
      AwsError.unwrapOptionField("action", action)
    def getArn: ZIO[Any, AwsError, Arn] = AwsError.unwrapOptionField("arn", arn)
    def getCreatedAt: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("createdAt", createdAt)
    def getEvent
        : ZIO[Any, AwsError, zio.aws.dataexchange.model.Event.ReadOnly] =
      AwsError.unwrapOptionField("event", event)
    def getId: ZIO[Any, AwsError, Id] = AwsError.unwrapOptionField("id", id)
    def getUpdatedAt: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("updatedAt", updatedAt)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.dataexchange.model.CreateEventActionResponse
  ) extends zio.aws.dataexchange.model.CreateEventActionResponse.ReadOnly {
    override val action: Optional[zio.aws.dataexchange.model.Action.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.action())
        .map(value => zio.aws.dataexchange.model.Action.wrap(value))
    override val arn: Optional[Arn] = zio.aws.core.internal
      .optionalFromNullable(impl.arn())
      .map(value => zio.aws.dataexchange.model.primitives.Arn(value))
    override val createdAt: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.createdAt())
      .map(value => zio.aws.dataexchange.model.primitives.Timestamp(value))
    override val event: Optional[zio.aws.dataexchange.model.Event.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.event())
        .map(value => zio.aws.dataexchange.model.Event.wrap(value))
    override val id: Optional[Id] = zio.aws.core.internal
      .optionalFromNullable(impl.id())
      .map(value => zio.aws.dataexchange.model.primitives.Id(value))
    override val updatedAt: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.updatedAt())
      .map(value => zio.aws.dataexchange.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.dataexchange.model.CreateEventActionResponse
  ): zio.aws.dataexchange.model.CreateEventActionResponse.ReadOnly =
    new Wrapper(impl)
}
